#!/usr/bin/env python
import re
import requests
import StringIO
import json
import datetime

from Foundation import NSUserNotification
from Foundation import NSUserNotificationCenter
from Foundation import NSUserNotificationDefaultSoundName
from AppKit import NSImage

from optparse import OptionParser

def check_supply_status(host, level):
    r = requests.get(host + "/sws/app/information/supplies/supplies.json")

    json_text = StringIO.StringIO()

    for line in StringIO.StringIO(r.text):
        line = re.sub(r'(\w+)\ ?:', r'"\1":', line.strip())
        json_text.write(line)

    toner_json = json.loads(json_text.getvalue())
    toner_msg = ""

    for color in ["black", "cyan", "magenta", "yellow"]:

        toner_key = "toner_" + color

        if (toner_key in toner_json):

            toner_level = toner_json[toner_key]["remaining"]

            if int(toner_level) < int(level):
                toner_msg += color.title() + " @ " + str(toner_level) + "% "

    if toner_msg:
        alert(toner_msg)

def alert(message):

    # load printer icon
    icon = NSImage.alloc().initWithContentsOfFile_("printer.png")

    # create notification
    notification = NSUserNotification.alloc().init()
    notification.setTitle_("Print Levels Alert")
    notification.setSubtitle_(message)
    notification.setContentImage_(icon)

    # create identifier
    id = "TONERATE_" + datetime.datetime.now().strftime("%Y%m%d")
    notification.setIdentifier_(id)

    notification.setSoundName_(NSUserNotificationDefaultSoundName)

    center = NSUserNotificationCenter.defaultUserNotificationCenter()
    center.deliverNotification_(notification)

def main():
    parser = OptionParser(usage='%prog -u URL to printer -l Minimum toner level percentage')
    parser.add_option('-u', '--url', action='store', default='http://localhost')
    parser.add_option('-l', '--level', action='store', default='21')

    options, args = parser.parse_args()

    check_supply_status(options.url, options.level)


if __name__ == '__main__':
    main()
